<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package AI Blog Pro Content Generator
 */

namespace Amasty\AiBlogProContentGenerator\Model\Entity\PayloadModifier;

use Amasty\AiContentGenerator\Api\Entity\PayloadModifierInterface;
use Amasty\OpenaiCore\Api\Data\PayloadInterface;
use Magento\Framework\Exception\LocalizedException;

class FieldPayloadModifier implements PayloadModifierInterface
{
    /**
     * @var PayloadModifierInterface[]
     */
    private $modifiers;

    public function __construct(
        array $modifiers = []
    ) {
        $this->initModifiers($modifiers);
    }

    /**
     * @param PayloadInterface $payload
     */
    public function modify(PayloadInterface $payload): void
    {
        if (empty($this->modifiers[$payload->getContentField()])) {
            return;
        }
        foreach ($this->modifiers[$payload->getContentField()] as $modifier) {
            $modifier->modify($payload);
        }
    }

    /**
     * @param array $modifiers
     * @throws LocalizedException
     */
    private function initModifiers(array $modifiers): void
    {
        foreach ($modifiers as $key => $modifierArray) {
            foreach ($modifierArray as $modifier) {
                if (!$modifier instanceof PayloadModifierInterface) {
                    throw new LocalizedException(
                        __('Payload modifier must be implements %1', PayloadModifierInterface::class)
                    );
                }
            }
            $this->modifiers[$key] = $modifierArray;
        }
    }
}
