<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package AI Blog Pro Content Generator
 */

namespace Amasty\AiBlogProContentGenerator\Model\Entity\PayloadResolver\Blog\Post;

use Amasty\AiBlogProContentGenerator\Model\Entity\PayloadModifier\FieldPayloadModifier;
use Amasty\AiContentGenerator\Api\Entity\PayloadResolverInterface;
use Amasty\AiContentGenerator\Model\PayloadConfigProvider;
use Amasty\Blog\Api\PostRepositoryInterface;
use Amasty\OpenaiCore\Api\Data\PayloadInterface;
use Amasty\OpenaiCore\Model\PayloadConfig;

class FullContent implements PayloadResolverInterface
{
    /**
     * @var PostRepositoryInterface
     */
    protected $postRepository;

    /**
     * @var PayloadConfigProvider
     */
    protected $payloadConfigProvider;

    /**
     * @var FieldPayloadModifier
     */
    private $fieldPayloadModifier;

    public function __construct(
        PostRepositoryInterface $postRepository,
        PayloadConfigProvider $payloadConfigProvider,
        FieldPayloadModifier $fieldPayloadModifier
    ) {
        $this->postRepository = $postRepository;
        $this->payloadConfigProvider = $payloadConfigProvider;
        $this->fieldPayloadModifier = $fieldPayloadModifier;
    }

    public function resolve(PayloadInterface $payload): PayloadInterface
    {
        $payload->setConfig($this->getConfig($payload));
        if ($payload->getPrompt()) {
            return $payload;
        }
        $this->fieldPayloadModifier->modify($payload);
        $payload->setPrompt($this->getCommand() . $payload->getPrompt());

        return $payload;
    }

    public function getConfig(PayloadInterface $payload): PayloadConfig
    {
        return $this->payloadConfigProvider->get($payload);
    }

    public function getCommand(): string
    {
        return (string)__('Write a blog post full content based on: ');
    }
}
